=========================
django-codenerix-payments
=========================

Codenerix Payments is a module that enables `CODENERIX <http://www.codenerix.com/>`_ to manage payments and let clients to pay online.

.. image:: http://www.codenerix.com/wp-content/uploads/2018/05/codenerix.png
    :target: http://www.codenerix.com
    :alt: Try our demo with Codenerix Cloud

********
Features
********

* `Paypal <https://www.paypal.com/>`_
* `Redsys <http://www.redsys.es/en/>`_

*********
Changelog
*********

2018-01-17 - Codenerix Payments v1.x is incompatible with v2.x, `what has changed and how to migrate to v2.x? <https://github.com/codenerix/django-codenerix-payments/wiki/Codenerix-Payments-version-1.x-is-icompatible-with-2.x>`_.

****
Demo
****

Comin soon...

**********
Quickstart
**********

1. Install this package::

    For python 2: sudo pip2 install django-codenerix-payments
    For python 3: sudo pip3 install django-codenerix-payments

2. Add "codenerix_payments" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'codenerix_payments',
    ]

3. Since Codenerix Payments is a library, you only need to import its parts into your project and use them.

*************
Documentation
*************

Coming soon... do you help us? `Codenerix <http://www.codenerix.com/>`_

You can chat with us `here <https://goo.gl/NgpzBh>`_.

*******
Credits
*******

This project has been possible thanks to `Centrologic <http://www.centrologic.com/>`_.
